@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkAbstractMapper3D extends vtkAbstractMapper
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -47,10 +47,6 @@ public class vtkAbstractMapper3D extends vtkAbstractMapper
   public void GetClippingPlaneInDataCoords(vtkMatrix4x4 id0,int id1,double id2[])
     { GetClippingPlaneInDataCoords_9(id0,id1,id2); }
 
-  private native int GetNumberOfClippingPlanes_10();
-  public int GetNumberOfClippingPlanes()
-    { return GetNumberOfClippingPlanes_10(); }
-
   public vtkAbstractMapper3D() { super(); }
 
   public vtkAbstractMapper3D(long id) { super(id); }
